@@ -154,6 +154,37 @@ package Sidef::Math::Math {
         Sidef::Types::Array::Array->new(\@y);
     }
 
+    sub gcd_factors {
+        my ($self, $n, $arr) = @_;
+
+        my $orig_n = $n;
+
+        my @factors;
+        my $G = Sidef::Types::Array::Array->new([grep { $_->is_ntf($n) } map { $n->gcd($_) } @$arr])->sort->uniq;
+
+        foreach my $g (@$G) {
+
+            my $new_g = $g;
+
+            if ($new_g->divides($n)) {
+                ## ok
+            }
+            else {
+                $new_g = $n->gcd($g);
+                $new_g->is_ntf($n) || next;
+            }
+
+            push @factors, $new_g;
+            $n = $n->remove($new_g);
+        }
+
+        if ($n->is_ntf($orig_n)) {
+            push @factors, $n;
+        }
+
+        Sidef::Types::Array::Array->new(\@factors)->sort;
+    }
+
     sub smooth_numbers {
         my ($self, @primes) = @_;
 
